function ssc_files, time0, time1, count=count, topdir=topdir, $
  extension=extension,  debug=debug, $
  sss_files=sss_files, sxh_files=sxh_files, collapse=collapse 
;
;+
;   Name: ssc_files
;
;   Purpose: return SXT ssc (or sss/sxh) file names from user times
;
;   Input Parameters:
;      time0 - time to match or start time of range
;      time1 - end time of range
;
;   Keyword Parameters:
;      count - number of files returned
;      topdir - optional top level path (default via env: DIR_SXT_{SSC/SSS/SXH
;      sss_files (switch) if set, consider SSS files ("show" movie"
;      sxh_files (switch) if set, consider SXH files (histograms)
;      extension - ssc processing flags<=>file extension
;      collapse - if set, assume all files in top level  
;                 (default is yearly subdirect: <toplev>/YYYY/xxxyyyy...
;     
;   History:
;      6-July-2000 - S.L.Freeland - helper routine 
;
;   Method: 
;      ssw standards like anytim, sel_filetimes, get_logenv,...
;-
debug=keyword_set(debug)

count=0
sss_files=keyword_set(sss_files)
sxh_files=keyword_set(sxh_files)
parent=''
case 1 of 
    data_chk(topdir,/string): parent=topdir
    sss_files: parent=get_logenv('DIR_SXT_SSS')
    sxh_files: parent=get_logenv('DIR_SXT_SXH')
    else: parent=get_logenv('DIR_SXT_SSC')
endcase
if parent eq '' then begin 
   box_message,['Parent diectory not defined',$
                'Set DIR_SXT_SSC or use TOPDIR="/path"']
   return,''
endif

collapse=keyword_set(collapse) or sxh_files

prefix=strsplit(parent,'/',/last,/tail)

case n_params() of 
   0: begin 
         t0=get_yo_dates(/launch)
         t1=reltime(/now,out='yohkoh')
   endcase
   1: begin
         time_window,time0,t0,t1,/day
   endcase
   else: begin
      t0=anytim(time0,/yohkoh)
      t1=anytim(time1,/yohkoh)
         
   endcase
endcase

tgrid=timegrid(t0,t1,/day)
fgrid=time2file(tgrid,/date_only)
ygrid=strmid(fgrid,0,4)                    ; YYYY

case 1 of
   data_chk(extension,/string):
   keyword_set(all): extension='*'
   else: extension='_001011.1'
endcase 

case 1 of 
   collapse: dirlist=parent
   else: begin 
      dirlist=concat_dir(parent,ygrid)
   endcase 
endcase
dirlist=dirlist(uniq(dirlist,sort(dirlist)))

files=sel_filetimes(t0,t1,filter=prefix+'*'+extension,$
              dir=dirlist)
if n_params() eq 1 and files(0) ne '' then files=files(tim2dset(file2time(files),time0))
if debug then stop,'files
count=n_elements(files)*(files(0) ne '' )
return,files
return,files
end
